@@ -28,7 +28,7 @@ class PrinterinfoPlugin(octoprint.plugin.EventHandlerPlugin):
         if profile:
             # send the printer name to the external API endpoint
             printer_name = profile.get("name")
-            self._logger.info(printer_name + "aquired")
+            self._logger.info(printer_name)
             self._send_printer_name(printer_name)
 
     def _handle_print_started(self, payload):
@@ -36,7 +36,7 @@ class PrinterinfoPlugin(octoprint.plugin.EventHandlerPlugin):
         job_data = self._printer.get_current_job()
         if job_data:
             # send the print job data to the external API endpoint
-            self._logger.info(job_data + "aquired")
+            self._logger.info(job_data)
             self._send_print_job_data(job_data)
 
     def _send_printer_name(self, printer_name):
